@@ -11,7 +11,7 @@ END
  
 }
 
-VERSION_UEILIST='$Revision: 5614 $'
+VERSION_UEILIST='$Revision: 7724 $'
 
 ulimit -s 2048
  
@@ -32,7 +32,7 @@ else
         fi
 fi
 
-OPENNMS_HOME="/space/svn/trunk/target/opennms-1.3.3"
+OPENNMS_HOME="/home/ranger/cvs/opennms-trunk/target/opennms-1.3.8"
 
 # load libraries
 for script in pid_process arg_process build_classpath check_tools \
