@@ -17,7 +17,7 @@ else
 	fi
 fi
 
-OPENNMS_HOME="/space/svn/trunk/target/opennms-1.3.3"
+OPENNMS_HOME="/home/ranger/cvs/opennms-trunk/target/opennms-1.3.8"
 LOG4J_CONFIG="events.archiver.properties"
 
 # load libraries
