@@ -17,7 +17,7 @@ SQL_FILE="$1"; shift
 LOG_FILE="/tmp/unicode-convert.log"
 
 if [ -z "$SQL_FILE" ]; then
-	SQL_FILE=/space/svn/trunk/target/opennms-1.3.3/etc/create.sql
+	SQL_FILE=/home/ranger/cvs/opennms-trunk/target/opennms-1.3.8/etc/create.sql
 fi
 
 FILE="/tmp/pg_dump-${DATABASE}"
